@@ -3,24 +3,21 @@ use crate::Message;
 use crate::Network;
 use crate::Peer;
 use fides::chacha20poly1305;
-use rand::Rng;
-use std::net::UdpSocket;
+use std::sync::Arc;
 
 impl Network {
 
     pub fn send(&self, message: Message, peer: Peer) {
 
-        println!("pulsar: sending message to {} ...", peer.address);
+        let outgoing_socket_clone = Arc::clone(&self.outgoing_socket);
 
-        let port: u16 = rand::thread_rng().gen_range(49152..65535);
-
-        let socket = UdpSocket::bind(format!("127.0.0.1:{}", port)).expect("couldn't bind to address, try again!");
+        let outgoing_socket = outgoing_socket_clone.lock().unwrap();
 
         let cipher = chacha20poly1305::encrypt(&peer.shared_key, &message.into_bytes());
         
         let msg = [vec![5], self.public_key.to_vec(), cipher].concat();
         
-        socket.send_to(&msg, peer.address).unwrap();
+        outgoing_socket.send_to(&msg, peer.address).unwrap();
 
     }
 }
\ No newline at end of file
